summaryrefslogtreecommitdiffstats
path: root/openpgp/src/parse.rs
diff options
context:
space:
mode:
authorJustus Winter <justus@sequoia-pgp.org>2022-05-03 12:09:50 +0200
committerJustus Winter <justus@sequoia-pgp.org>2022-05-03 12:09:50 +0200
commit19f50dd723d7e5c6e3260536af624203b514381c (patch)
tree59f15af9a3aae67feabf50121f0f73f9f799c8cf /openpgp/src/parse.rs
parent583f781a0fb66b503c492540510eb747c6f47247 (diff)
openpgp: Rename function.
Diffstat (limited to 'openpgp/src/parse.rs')
-rw-r--r--openpgp/src/parse.rs6
1 files changed, 3 insertions, 3 deletions
diff --git a/openpgp/src/parse.rs b/openpgp/src/parse.rs
index 386c27b5..c8b329fd 100644
--- a/openpgp/src/parse.rs
+++ b/openpgp/src/parse.rs
@@ -4166,7 +4166,7 @@ impl <'a> PacketParser<'a> {
}
}
/// Returns Ok if the data appears to be a legal packet.
///
/// This is just a heuristic. It can be used for recovering from
/// garbage.
@@ -4183,7 +4183,7 @@ impl <'a> PacketParser<'a> {
///
/// Currently, we only try to recover the most interesting
/// packets.
- fn plausible<T: BufferedReader<Cookie>>(
+ fn plausible_cert<T: BufferedReader<Cookie>>(
bio: &mut buffered_reader::Dup<T, Cookie>, header: &Header)
-> Result<()> {
let bad = Err(
@@ -4278,7 +4278,7 @@ impl <'a> PacketParser<'a> {
break;
}
- match Self::plausible(&mut bio, &header_) {
+ match Self::plausible_cert(&mut bio, &header_) {
Ok(()) => {
header = header_;
break;
@@ -4166,7 +4166,7 @@ impl <'a> PacketParser<'a> {
}
}
- /// Returns Ok if the data appears to be a legal packet.
+ /// Tests whether the data appears to be a legal cert packet.
///
/// This is just a heuristic. It can be used for recovering from